import GPLinearODEMaker.powers_of_negative_one

"""
    qp_kernel(hyperparameters, δ, dorder; shift_ind=0)

Created by kernel_coder(). Requires 3 hyperparameters.
Likely created using qp_kernel_base() as an input.
Use with include("src/kernels/qp_kernel.jl").

# Arguments
- `hyperparameters::Vector`: The hyperparameter values. For this kernel, they should be `["qp_P", "se_λ", "p_amp"]`
- `δ::Real`: The difference between the inputs (e.g. `t1 - t2`)
- `dorder::Vector{<:Integer}`: How many times to differentiate with respect to the inputs and the `hyperparameters` (e.g. `dorder=[0, 1, 0, 2]` would correspond to differentiating once w.r.t the second input and twice w.r.t `hyperparameters[2]`)
- `shift_ind::Integer=0`: If changed, the index of which hyperparameter is the `δ` shifting one
"""
function qp_kernel(
    hyperparameters::Vector{<:Real},
    δ::Real,
    dorder::Vector{<:Integer};
    shift_ind::Integer=0)

    include_shift = shift_ind!=0
    @assert length(hyperparameters)==3+Int(include_shift) "hyperparameters is the wrong length"
    dorder_len = 5 + Int(include_shift)
    @assert length(dorder)==dorder_len "dorder is the wrong length"
    @assert maximum(dorder) < 3 "No more than two derivatives for each time or hyperparameter can be calculated"

    dorder2 = dorder[2]
    dorder[2] += dorder[1]

    if include_shift
        dorder[2] += dorder[shift_ind+2]
        δ += hyperparameters[shift_ind]
        hyperparameters_view = view(hyperparameters, 1:4 .!= shift_ind)
        dorder_view = view(dorder, 2:dorder_len)
        dorder_view = view(dorder_view, 1:(dorder_len-1) .!= (shift_ind+1))
    else
        hyperparameters_view = hyperparameters
        dorder_view = view(dorder, 2:dorder_len)
    end

    qp_P = hyperparameters_view[1]
    se_λ = hyperparameters_view[2]
    p_amp = hyperparameters_view[3]

    if dorder_view==[6, 0, 0, 2]
        func = -4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6*sin(δ*π/qp_P)^2 + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4 + 45*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2 + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2 + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) - 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3*sin(δ*π/qp_P)^2 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6*sin(δ*π/qp_P)^4 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3*sin(δ*π/qp_P)^4 + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^6*sin(δ*π/qp_P)^2/qp_P^6 - 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^6*cos(δ*π/qp_P)^2/qp_P^6 - 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2 - 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) + 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^4 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4 - 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^6*sin(δ*π/qp_P)^4/qp_P^6 + 1024*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^6*sin(δ*π/qp_P)^6/qp_P^6 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/qp_P^4 + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^4 + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^4 - 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)^2 - 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2 + 47360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^6 + 30720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^4/qp_P^6 - 148480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^6*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^6 + 40960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^6*π^6*sin(δ*π/qp_P)^6*cos(δ*π/qp_P)^2/qp_P^6 - 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 + 4800*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^4/qp_P^4 + 4800*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4/qp_P^4 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^6/qp_P^4 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^6/qp_P^4 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^4 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^4 - 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*π^4*sin(δ*π/qp_P)^2/qp_P^4 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*π^4*cos(δ*π/qp_P)^2/qp_P^4 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^3*π^4*sin(δ*π/qp_P)^4/qp_P^4 - 19200*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^5 + 26880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^5 + 153600*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^5 - 36864*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^5*cos(δ*π/qp_P)/qp_P^5 - 43200*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 - 43200*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 65280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^4 + 65280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^4 - 6400*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 + 5120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^5*cos(δ*π/qp_P)/qp_P^3 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^2 + 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^2 + 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P - 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 17280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^3*π^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 - 19200*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 + 15360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^5*cos(δ*π/qp_P)/qp_P^3 + 11520*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^2 + 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 7680*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P
    end

    if dorder_view==[5, 0, 0, 2]
        func = -4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)^2 + 10*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3 + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P) + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)^4 - 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2 - 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^4 + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4 - 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 - 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/qp_P^4 + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/qp_P^4 - 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2 - 3200*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^5 + 4480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^5 + 25600*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^5 - 6144*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^5*sin(δ*π/qp_P)^5*cos(δ*π/qp_P)/qp_P^5 + 1600*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^4/qp_P^4 - 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^6/qp_P^4 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 - 14400*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 21760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^4 - 3200*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 - 3200*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 + 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^5*cos(δ*π/qp_P)/qp_P^3 + 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^5*cos(δ*π/qp_P)/qp_P^3 + 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^2 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^3*π^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^2 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P
    end

    if dorder_view==[4, 0, 0, 2]
        func = 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)^2 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)^2 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) - 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)^4 + 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^4 - 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^4*sin(δ*π/qp_P)^2/qp_P^4 + 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^4*cos(δ*π/qp_P)^2/qp_P^4 - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 + 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*sin(δ*π/qp_P)^4/qp_P^4 - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^4*sin(δ*π/qp_P)^6/qp_P^4 - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2 - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 4352*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^4*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^4 + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 + 1024*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^5*cos(δ*π/qp_P)/qp_P^3 + 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^2 + 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^2 + 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P - 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P + 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P - 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P
    end

    if dorder_view==[3, 0, 0, 2]
        func = -4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2 + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P) + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^4 - 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 + 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4 + 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2 - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 + 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^3*sin(δ*π/qp_P)^5*cos(δ*π/qp_P)/qp_P^3 - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P + 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^2 + 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P + 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P
    end

    if dorder_view==[2, 0, 0, 2]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*π^2*cos(δ*π/qp_P)^2/qp_P^2) - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^4 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4 - 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp*sin(δ*π/qp_P)^2 + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^2 - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P
    end

    if dorder_view==[1, 0, 0, 2]
        func = -4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^4 - 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P
    end

    if dorder_view==[0, 0, 0, 2]
        func = -4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*sin(δ*π/qp_P)^2 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*sin(δ*π/qp_P)^4
    end

    if dorder_view==[6, 0, 1, 1]
        func = 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2/se_λ^3 + 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 - 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)^2/se_λ^3 - 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2/se_λ^3 + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3/se_λ^3 + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4/se_λ^3 + 45*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^3 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*sin(δ*π/qp_P)^4/(qp_P^4*se_λ^3) - 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/se_λ^3 - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)^2/se_λ^3 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6*sin(δ*π/qp_P)^2/se_λ^3 - 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3*sin(δ*π/qp_P)^2/se_λ^3 + 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 - 17280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) - 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2/se_λ^3 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/se_λ^3 + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^6*sin(δ*π/qp_P)^2/(qp_P^6*se_λ^3) - 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^6*cos(δ*π/qp_P)^2/(qp_P^6*se_λ^3) - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^6*sin(δ*π/qp_P)^4/(qp_P^6*se_λ^3) - 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2/se_λ^3 - 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/se_λ^3 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 7680*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 1536*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^5*se_λ^3) - 7680*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/(qp_P^5*se_λ^3) + 10752*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^5*se_λ^3) - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^4/(qp_P^4*se_λ^3) + 13568*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^6*se_λ^3) - 10240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^5*π^6*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/(qp_P^6*se_λ^3) - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^4/(qp_P^4*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4/(qp_P^4*se_λ^3) - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 34560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 7680*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 7680*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 1440*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^5*se_λ^3) - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/(qp_P^5*se_λ^3) + 5376*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^5*se_λ^3) - 8640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) - 8640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3)
    end

    if dorder_view==[5, 0, 1, 1]
        func = 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)/se_λ^3 - 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2/se_λ^3 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2/se_λ^3 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 10*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3/se_λ^3 - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/se_λ^3 - 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)^2/se_λ^3 - 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2/se_λ^3 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)^2/se_λ^3 + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*sin(δ*π/qp_P)^4/(qp_P^4*se_λ^3) - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/se_λ^3 - 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2/se_λ^3 - 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/se_λ^3 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) - 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^5*se_λ^3) - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/(qp_P^5*se_λ^3) + 896*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^5*se_λ^3) - 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^4/(qp_P^4*se_λ^3) + 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3)
    end

    if dorder_view==[4, 0, 1, 1]
        func = 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)/se_λ^3 - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/se_λ^3 - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/se_λ^3 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)/se_λ^3 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2/se_λ^3 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 - 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2/se_λ^3 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)^2/se_λ^3 - 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2/se_λ^3 - 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/se_λ^3 - 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^4*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^4*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^4*sin(δ*π/qp_P)^4/(qp_P^4*se_λ^3) - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/se_λ^3 - 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) + 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 512*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 576*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) - 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3)
    end

    if dorder_view==[3, 0, 1, 1]
        func = 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ/se_λ^3 - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/se_λ^3 + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)/se_λ^3 - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/se_λ^3 - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/se_λ^3 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2/se_λ^3 - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/se_λ^3 + 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^3*π^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3)
    end

    if dorder_view==[2, 0, 1, 1]
        func = -8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*sin(δ*π/qp_P)^2/se_λ^3 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ^2/se_λ^3 - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/se_λ^3 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/se_λ^3 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/se_λ^3 - 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3) - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3)
    end

    if dorder_view==[1, 0, 1, 1]
        func = -8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*sin(δ*π/qp_P)^2/se_λ^3 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/se_λ^3 - 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P*se_λ^3)
    end

    if dorder_view==[0, 0, 1, 1]
        func = -4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp*sin(δ*π/qp_P)^2/se_λ^3
    end

    if dorder_view==[6, 1, 0, 1]
        func = 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(-16*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 16*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 32*δ*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4) + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 45*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-16*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 16*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 32*δ*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2 + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-16*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 16*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 32*δ*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4) + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) - 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^2 - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2 - 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2 - 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^6*sin(δ*π/qp_P)^2/qp_P^7 + 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^6*cos(δ*π/qp_P)^2/qp_P^7 + 1536*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^6*sin(δ*π/qp_P)^4/qp_P^7 + 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) - 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2 - 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2 - 78336*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^7 + 61440*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^5*π^6*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^7 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/qp_P^5 - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^5 - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^5 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^4/qp_P^5 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4/qp_P^5 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^2/qp_P^4 + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*cos(δ*π/qp_P)^2/qp_P^4 - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-16*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 16*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 32*δ*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^2/qp_P^4 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-16*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 16*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 32*δ*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*cos(δ*π/qp_P)^2/qp_P^4 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^4/qp_P^4 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^5 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^5 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 + 15360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^6 - 23040*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^6 - 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^5*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 - 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^5*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 + 26880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 + 26880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^5*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^5 + 5376*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^5*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^5 - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/qp_P^4 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/qp_P^4 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/qp_P^4 + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/qp_P^4 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^4 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^4/qp_P^4 - 8640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 - 512*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^7*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^8 - 24576*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^7*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^8 + 25600*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^7*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^8 + 95232*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^7*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^8 - 21504*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^7*sin(δ*π/qp_P)^5*cos(δ*π/qp_P)/qp_P^8 - 40960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^7*π^7*sin(δ*π/qp_P)^5*cos(δ*π/qp_P)^3/qp_P^8 - 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/qp_P^7 + 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/qp_P^7 + 1536*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^4/qp_P^7 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2/qp_P^5 - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*cos(δ*π/qp_P)^2/qp_P^5 - 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^4/qp_P^5 - 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 + 11520*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^4 - 17280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-16*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 16*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 32*δ*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 23040*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^7 - 15360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^4/qp_P^7 + 21504*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^7 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 + 11520*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^6 - 15360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^6 + 11520*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^6 - 15360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^6 - 34560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^6 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^5*cos(δ*π/qp_P)/qp_P^6 - 34560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^6 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^5*cos(δ*π/qp_P)/qp_P^6 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^5 - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^5 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4/qp_P^5 + 6400*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 - 5120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^5 - 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^3 + 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2 - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2 - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^2*π^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^4*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^6 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^4*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^6 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/qp_P^5 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/qp_P^5 - 1440*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 1440*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P + 19200*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 - 15360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^5 - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^3 - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^3 + 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2 - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[5, 1, 0, 1]
        func = 10*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(-16*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 16*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 32*δ*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4) + 5*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-16*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 16*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 32*δ*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4) + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) - 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^2 - 20*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2 - 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2 - 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 - 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 + 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^6 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^6 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/qp_P^5 - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/qp_P^5 - 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^4/qp_P^5 - 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/qp_P^4 + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/qp_P^4 - 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/qp_P^4 + 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/qp_P^4 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^4/qp_P^4 - 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^6*sin(δ*π/qp_P)^2/qp_P^7 + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^6*cos(δ*π/qp_P)^2/qp_P^7 + 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^6*sin(δ*π/qp_P)^4/qp_P^7 + 8960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^4 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^4 - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-16*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 16*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 32*δ*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^7 - 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^4/qp_P^7 + 3584*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^6*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^7 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/qp_P^5 - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^5 - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^5 - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^4/qp_P^5 - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4/qp_P^5 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^5 - 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^5 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^6 - 5120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^6 - 11520*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^6 + 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^5*cos(δ*π/qp_P)/qp_P^6 + 3200*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 + 3200*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 - 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^5 - 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^5 - 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^3 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^3 + 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^4*π^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^3 + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2 - 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2 + 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[4, 1, 0, 1]
        func = 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-16*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 16*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 32*δ*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4) + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4) + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-16*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 16*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 32*δ*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^2 - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2 - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*sin(δ*π/qp_P)^2/qp_P^5 - 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*cos(δ*π/qp_P)^2/qp_P^5 - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*sin(δ*π/qp_P)^4/qp_P^5 - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2 + 1792*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 - 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 + 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^4 + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 + 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^6 - 1024*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^6 - 2304*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^6 + 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^5*sin(δ*π/qp_P)^5*cos(δ*π/qp_P)/qp_P^6 + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/qp_P^5 - 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/qp_P^5 - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^4/qp_P^5 - 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P + 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 - 1024*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^5 - 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^3 + 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2 - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2 - 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^3 + 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[3, 1, 0, 1]
        func = 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-16*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 16*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 32*δ*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4) + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3) - 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^2 - 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2 - 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2 - 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 + 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^4 + 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*sin(δ*π/qp_P)^2/qp_P^5 - 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π^4*cos(δ*π/qp_P)^2/qp_P^5 - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*sin(δ*π/qp_P)^4/qp_P^5 - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^5*π^4*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^5 - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^3 - 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^3 + 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2 + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[2, 1, 0, 1]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-16*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 16*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 32*δ*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4) + 2*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3) - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^2 - 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2 - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^3 + 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2 - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2 + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*δ*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[1, 1, 0, 1]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 8*δ*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*δ*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^3) - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2 - 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^3 + 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[0, 1, 0, 1]
        func = 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^3*π*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[6, 0, 0, 1]
        func = 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4 + 45*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6*sin(δ*π/qp_P)^2 - 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3*sin(δ*π/qp_P)^2 + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) - 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2 - 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^6*sin(δ*π/qp_P)^2/qp_P^6 - 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^6*cos(δ*π/qp_P)^2/qp_P^6 - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^6*sin(δ*π/qp_P)^4/qp_P^6 + 13568*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^6 - 10240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^5*π^6*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^6 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/qp_P^4 + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^4 + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^4 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^4/qp_P^4 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4/qp_P^4 - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^4 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^4 - 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^5 + 5376*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^5 - 8640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 - 8640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 - 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3
    end

    if dorder_view==[5, 0, 0, 1]
        func = 10*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)^2 + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) - 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2 - 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 - 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^5 + 896*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^5 - 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/qp_P^4 + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/qp_P^4 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^4/qp_P^4 - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 - 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P
    end

    if dorder_view==[4, 0, 0, 1]
        func = 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)^2 - 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2 - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 - 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*sin(δ*π/qp_P)^2/qp_P^4 + 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^4*cos(δ*π/qp_P)^2/qp_P^4 + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*sin(δ*π/qp_P)^4/qp_P^4 - 576*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 - 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P
    end

    if dorder_view==[3, 0, 0, 1]
        func = 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P) - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2 - 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 + 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^3*π^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^3 - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P
    end

    if dorder_view==[2, 0, 0, 1]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(8*p_amp*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 8*p_amp*π^2*cos(δ*π/qp_P)^2/qp_P^2) - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2 - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P
    end

    if dorder_view==[1, 0, 0, 1]
        func = -4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2 - 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P
    end

    if dorder_view==[0, 0, 0, 1]
        func = -4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp*sin(δ*π/qp_P)^2
    end

    if dorder_view==[6, 0, 2, 0]
        func = 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2/se_λ^6 + 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^6 - 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4/se_λ^4 - 270*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^4 - 540*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^4 + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3/se_λ^6 - 36*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5/se_λ^4 + 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4/se_λ^6 + 540*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^6 - 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6/se_λ^4 - 45*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3/se_λ^4 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5/se_λ^6 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6/se_λ^6 + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3/se_λ^6 + 1440*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^6 - 540*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^4 - 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^4 + 1080*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^6 - 135*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^4 - 45*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^4 + 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^6 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^6 + 45*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^6 + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^6 + 1440*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^4) - 1440*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^4) - 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^6*sin(δ*π/qp_P)^2/(qp_P^6*se_λ^4) + 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^6*cos(δ*π/qp_P)^2/(qp_P^6*se_λ^4) - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^6) + 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^6) + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^6*sin(δ*π/qp_P)^2/(qp_P^6*se_λ^6) - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^6*cos(δ*π/qp_P)^2/(qp_P^6*se_λ^6) - 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^4) + 2304*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^5*se_λ^4) + 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^4) - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^4) + 7680*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^6) - 7680*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^6*se_λ^4) + 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^4) - 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^4) + 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^4) - 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^4) - 1536*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^5*se_λ^6) - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^6) + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^6) + 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^4*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^6*se_λ^6) - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^6) + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^6) - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^6) + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^6) - 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^4) - 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^4) + 1152*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^5*se_λ^4) + 11520*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^6) - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^4) + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^6) + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^6) - 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^5*se_λ^6) + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^6) - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^4) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^6)
    end

    if dorder_view==[5, 0, 2, 0]
        func = 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)/se_λ^6 - 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3/se_λ^4 - 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^4 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2/se_λ^6 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^6 - 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4/se_λ^4 - 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^4 + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3/se_λ^6 - 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5/se_λ^4 + 20*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4/se_λ^6 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^6 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5/se_λ^6 - 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^4 + 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^6 - 45*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^4 - 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^4 + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^6 + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^6 + 10*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^6 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^4) + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^4) - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^4) - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^6) + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^6) + 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^5*se_λ^4) + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^4) - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^4) + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^6) - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^5*se_λ^6) - 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^6) + 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^6) - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^4) - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^4) - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^4) + 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^6) + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^6) + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^6)
    end

    if dorder_view==[4, 0, 2, 0]
        func = 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)/se_λ^6 - 36*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2/se_λ^4 - 36*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^4 + 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)/se_λ^6 - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3/se_λ^4 + 72*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2/se_λ^6 + 72*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^6 - 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4/se_λ^4 - 9*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^4 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3/se_λ^6 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4/se_λ^6 + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^6 - 72*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^4 - 18*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^4 + 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^6 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^6 + 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^4) - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^4) - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^4*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^6) + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^4*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^6) - 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^4) + 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^6) - 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^4) + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^6)
    end

    if dorder_view==[3, 0, 2, 0]
        func = -18*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)/se_λ^4 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ/se_λ^6 - 18*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2/se_λ^4 - 18*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^4 + 36*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)/se_λ^6 - 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3/se_λ^4 + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2/se_λ^6 + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^6 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3/se_λ^6 - 9*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^4 + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^6 - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^4) + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^6)
    end

    if dorder_view==[2, 0, 2, 0]
        func = -6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)/se_λ^4 + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2/se_λ^6 - 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)/se_λ^4 - 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2/se_λ^4 - 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^4 + 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)/se_λ^6 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2/se_λ^6 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^6
    end

    if dorder_view==[1, 0, 2, 0]
        func = -6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ/se_λ^4 + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3/se_λ^6 - 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)/se_λ^4 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)/se_λ^6
    end

    if dorder_view==[0, 0, 2, 0]
        func = -3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2/se_λ^4 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^4/se_λ^6
    end

    if dorder_view==[6, 1, 1, 0]
        func = 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)/se_λ^3 + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)/se_λ^3 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)/se_λ^3 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 45*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^3 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*sin(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) + 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 - 1152*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^6*sin(δ*π/qp_P)^2/(qp_P^7*se_λ^3) + 1152*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^6*cos(δ*π/qp_P)^2/(qp_P^7*se_λ^3) - 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^4*se_λ^3) + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^6*se_λ^3) + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/(qp_P^6*se_λ^3) - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^6*se_λ^3) + 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) - 18432*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^7*se_λ^3) + 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) + 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^7*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^8*se_λ^3) - 5376*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^7*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/(qp_P^8*se_λ^3) + 5376*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^7*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^8*se_λ^3) + 10240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^6*π^7*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/(qp_P^8*se_λ^3) - 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/(qp_P^7*se_λ^3) + 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/(qp_P^7*se_λ^3) + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) + 7680*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^4*se_λ^3) - 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^4*se_λ^3) + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^6*se_λ^3) + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/(qp_P^6*se_λ^3) - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^6*se_λ^3) - 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^5*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^5*se_λ^3) + 7680*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) + 7680*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^4*se_λ^3) - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) - 1536*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^7*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^6*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^6*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/(qp_P^6*se_λ^3) - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^6*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/(qp_P^6*se_λ^3) - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^6*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) + 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^4*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) + 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3)
    end

    if dorder_view==[5, 1, 1, 0]
        func = 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)/se_λ^3 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)/se_λ^3 + 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 10*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)/se_λ^3 + 5*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^4*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*sin(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^6*sin(δ*π/qp_P)^2/(qp_P^7*se_λ^3) + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^6*cos(δ*π/qp_P)^2/(qp_P^7*se_λ^3) + 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^6*se_λ^3) + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/(qp_P^6*se_λ^3) - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^6*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^7*se_λ^3) + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^4*se_λ^3) + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^4*se_λ^3) - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^4*se_λ^3) + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^6*se_λ^3) + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/(qp_P^6*se_λ^3) - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^6*se_λ^3) + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3)
    end

    if dorder_view==[4, 1, 1, 0]
        func = 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)/se_λ^3 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)/se_λ^3 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)/se_λ^3 + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^4*se_λ^3) + 512*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^6*se_λ^3) + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/(qp_P^6*se_λ^3) - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/(qp_P^6*se_λ^3) + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) + 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) - 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^4*se_λ^3) + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3)
    end

    if dorder_view==[3, 1, 1, 0]
        func = 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)/se_λ^3 + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)/se_λ^3 + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*sin(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π^4*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^4*se_λ^3) + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^4*π^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^5*se_λ^3) + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3)
    end

    if dorder_view==[2, 1, 1, 0]
        func = 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)/se_λ^3 + 2*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3)
    end

    if dorder_view==[1, 1, 1, 0]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)/se_λ^3 + 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3) + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3)
    end

    if dorder_view==[0, 1, 1, 0]
        func = 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^3*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^2*se_λ^3)
    end

    if dorder_view==[6, 0, 1, 0]
        func = 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4/se_λ^3 + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^3 + 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5/se_λ^3 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6/se_λ^3 + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3/se_λ^3 + 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^3 + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 45*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^3 + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^6*sin(δ*π/qp_P)^2/(qp_P^6*se_λ^3) - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^6*cos(δ*π/qp_P)^2/(qp_P^6*se_λ^3) + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^5*se_λ^3) - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^6*se_λ^3) - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^5*se_λ^3) + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3)
    end

    if dorder_view==[5, 0, 1, 0]
        func = 20*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3/se_λ^3 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 10*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4/se_λ^3 + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^3 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5/se_λ^3 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^3 + 10*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) - 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^5*se_λ^3) - 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3)
    end

    if dorder_view==[4, 0, 1, 0]
        func = 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2/se_λ^3 + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3/se_λ^3 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4/se_λ^3 + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2/se_λ^3 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/(qp_P^4*se_λ^3) + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3) + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3)
    end

    if dorder_view==[3, 0, 1, 0]
        func = 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)/se_λ^3 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2/se_λ^3 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3/se_λ^3 + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/(qp_P^3*se_λ^3)
    end

    if dorder_view==[2, 0, 1, 0]
        func = 2*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)/se_λ^3 + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)/se_λ^3 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2/se_λ^3 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))/se_λ^3
    end

    if dorder_view==[1, 0, 1, 0]
        func = 2*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ/se_λ^3 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)/se_λ^3
    end

    if dorder_view==[0, 0, 1, 0]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2/se_λ^3
    end

    if dorder_view==[6, 2, 0, 0]
        func = 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)^2 + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)^2 + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(24*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 24*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 - 16*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^6 + 16*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^6 + 96*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5) + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5) + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)^2 + 45*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*(24*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 24*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 - 16*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^6 + 16*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^6 + 96*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5) + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2 + 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)^2 + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(24*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 24*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 - 16*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^6 + 16*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^6 + 96*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5) + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) + 2688*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^6*sin(δ*π/qp_P)^2/qp_P^8 - 2688*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^6*cos(δ*π/qp_P)^2/qp_P^8 + 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 107520*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^8 - 4800*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/qp_P^6 + 4800*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^6 - 4800*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^6 + 4800*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^6 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^2/qp_P^5 - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*cos(δ*π/qp_P)^2/qp_P^5 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)^2*sin(δ*π/qp_P)^2/qp_P^4 + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)^2*cos(δ*π/qp_P)^2/qp_P^4 - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(24*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 24*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 - 16*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^6 + 16*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^6 + 96*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*sin(δ*π/qp_P)^2/qp_P^4 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(24*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 24*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 - 16*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^6 + 16*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^6 + 96*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*cos(δ*π/qp_P)^2/qp_P^4 - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^8*sin(δ*π/qp_P)^2/qp_P^10 + 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^8*cos(δ*π/qp_P)^2/qp_P^10 + 5376*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^8*sin(δ*π/qp_P)^4/qp_P^10 + 5376*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^8*cos(δ*π/qp_P)^4/qp_P^10 - 11520*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^7 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^5*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/qp_P^5 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/qp_P^5 - 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^5*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*sin(δ*π/qp_P)^2/qp_P^4 + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*cos(δ*π/qp_P)^2/qp_P^4 + 3584*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^7*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^9 + 75264*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^7*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^9 - 75264*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^7*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^9 - 143360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^6*π^7*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^9 + 4608*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/qp_P^8 - 4608*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/qp_P^8 - 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^6*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/qp_P^7 + 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^6*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/qp_P^7 - 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2/qp_P^6 + 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*cos(δ*π/qp_P)^2/qp_P^6 - 33280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^8*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^10 - 52224*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^8*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^4/qp_P^10 + 52224*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^8*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^10 + 40960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^8*π^8*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^4/qp_P^10 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/qp_P^8 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^8 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^6*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^8 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^6*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^8 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^4/qp_P^8 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^4/qp_P^8 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^6*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4/qp_P^8 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^6*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^4/qp_P^8 + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6*sin(δ*π/qp_P)^2/qp_P^4 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6*cos(δ*π/qp_P)^2/qp_P^4 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3*sin(δ*π/qp_P)^2/qp_P^4 - 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3*cos(δ*π/qp_P)^2/qp_P^4 + 11520*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 - 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 - 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 - 5760*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(24*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 24*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 - 16*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^6 + 16*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^6 + 96*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 18432*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^8 - 9600*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^7 - 9600*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^7 - 9600*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^7 + 9600*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^7 - 9600*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^7 + 9600*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^7 - 3072*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^6*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^7 - 7680*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^6 + 7680*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^6 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^5*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 - 10240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^6 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^6 - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^6 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^2/qp_P^5 - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*cos(δ*π/qp_P)^2/qp_P^5 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/qp_P^5 - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/qp_P^5 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/qp_P^5 - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/qp_P^5 - 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 1536*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^7*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^9 + 4608*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^7*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^9 - 4608*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^7*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^9 - 6144*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^7*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^9 + 9600*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^8 + 9600*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^6*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^8 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^4/qp_P^8 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^8 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^6*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^4/qp_P^8 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^6*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^8 - 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^7 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^7 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^7 + 5120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^7 + 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2/qp_P^4 - 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*cos(δ*π/qp_P)^2/qp_P^4 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^4 - 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^4 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 - 30720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^6 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^6 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^6 + 7680*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 + 7680*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 + 7680*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 - 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^7 - 11520*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^7 + 11520*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^7 + 15360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^7 + 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 720*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[5, 2, 0, 0]
        func = 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)^2 + 20*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)^2 + 10*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(24*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 24*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 - 16*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^6 + 16*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^6 + 96*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5) + 5*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5) + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)^2 + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(24*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 24*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 - 16*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^6 + 16*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^6 + 96*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5) + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^7 - 1600*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/qp_P^6 + 1600*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/qp_P^6 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/qp_P^5 - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/qp_P^5 - 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*sin(δ*π/qp_P)^2/qp_P^4 + 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*cos(δ*π/qp_P)^2/qp_P^4 + 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^6*sin(δ*π/qp_P)^2/qp_P^8 - 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^6*cos(δ*π/qp_P)^2/qp_P^8 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(24*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 24*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 - 16*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^6 + 16*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^6 + 96*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 3072*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^8 - 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/qp_P^6 + 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^6 - 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^6 + 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^6 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^2/qp_P^5 - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*cos(δ*π/qp_P)^2/qp_P^5 + 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^7*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^9 + 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^7*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^9 - 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^7*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^9 - 1024*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^7*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^9 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/qp_P^8 - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/qp_P^8 - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^4/qp_P^8 - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^4/qp_P^8 + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)^2/qp_P^4 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*cos(δ*π/qp_P)^2/qp_P^4 - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 3200*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^7 - 3200*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^7 + 3200*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^7 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^5*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 - 5120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^6 - 5120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^6 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^6 - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^6 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/qp_P^5 - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/qp_P^5 + 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 - 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 3200*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^8 + 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^4/qp_P^8 - 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^8 - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^7 - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^7 - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^7 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^7 - 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^7 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^7 + 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^7 + 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^7 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2/qp_P^4 - 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*cos(δ*π/qp_P)^2/qp_P^4 + 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^4 - 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^4 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 - 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 120*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[4, 2, 0, 0]
        func = 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)^2 + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)^2 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(24*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 24*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 - 16*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^6 + 16*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^6 + 96*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5) + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5) + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)^2 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(24*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 24*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 - 16*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^6 + 16*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^6 + 96*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5) + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^6 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^6 + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^6*sin(δ*π/qp_P)^2/qp_P^8 - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^6*cos(δ*π/qp_P)^2/qp_P^8 - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^6*sin(δ*π/qp_P)^4/qp_P^8 - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^6*cos(δ*π/qp_P)^4/qp_P^8 + 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 - 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^7 - 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^7 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^7 - 512*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/qp_P^6 + 512*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/qp_P^6 + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/qp_P^5 - 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/qp_P^5 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^8 + 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^4/qp_P^8 - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^6*sin(δ*π/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^8 + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)^2/qp_P^4 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*cos(δ*π/qp_P)^2/qp_P^4 + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2/qp_P^4 - 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*cos(δ*π/qp_P)^2/qp_P^4 - 2048*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^6 + 512*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 - 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^7 - 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^7 + 768*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^7 + 1024*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^7 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^4 - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^4 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 32*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 96*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[3, 2, 0, 0]
        func = 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)^2 + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(24*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 24*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 - 16*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^6 + 16*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^6 + 96*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5) + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5) + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) + 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 - 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^6 + 128*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^6 - 512*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^6 - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^7 - 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^7 + 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^7 + 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^6*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^7 + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2/qp_P^4 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*cos(δ*π/qp_P)^2/qp_P^4 - 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^4 - 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^4 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 - 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4
    end

    if dorder_view==[2, 2, 0, 0]
        func = 2*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)^2 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(24*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 24*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 - 16*δ^2*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^6 + 16*δ^2*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^6 + 96*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5) + 2*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5) + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/qp_P^4 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^4 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^4 - 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[1, 2, 0, 0]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-8*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 16*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 + 16*δ^2*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5) + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/qp_P^4 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/qp_P^4 - 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4
    end

    if dorder_view==[0, 2, 0, 0]
        func = 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^4 - 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^4 - 8*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ^2*p_amp^4*π^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4
    end

    if dorder_view==[6, 1, 0, 0]
        func = 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4) + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 45*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2 + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 90*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) - 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^6*sin(δ*π/qp_P)^2/qp_P^7 + 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^6*cos(δ*π/qp_P)^2/qp_P^7 - 15360*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^7 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/qp_P^5 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^5 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^5 - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)^2/qp_P^4 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*cos(δ*π/qp_P)^2/qp_P^4 + 1920*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 - 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^5*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/qp_P^4 + 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/qp_P^4 - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^7*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^8 - 5376*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^7*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^8 + 5376*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^7*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^8 + 10240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^6*π^7*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)^3/qp_P^8 - 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/qp_P^7 + 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/qp_P^7 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2/qp_P^5 - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*cos(δ*π/qp_P)^2/qp_P^5 - 2880*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 1536*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^6*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^7 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^6 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^6 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^6 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^6 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^5 - 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^5 + 1280*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 3840*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 + 180*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[5, 1, 0, 0]
        func = 10*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4) + 5*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) + 30*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/qp_P^5 - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/qp_P^5 - 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)^2/qp_P^4 + 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*cos(δ*π/qp_P)^2/qp_P^4 - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^6*sin(δ*π/qp_P)^2/qp_P^7 + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^6*cos(δ*π/qp_P)^2/qp_P^7 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 - 480*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 - 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^7 + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/qp_P^5 - 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^5 - 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^5 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^6 - 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^6 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 + 640*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 60*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 40*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[4, 1, 0, 0]
        func = 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4) + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^5 - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^5 - 192*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^6 + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)^3/qp_P^6 - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^5*sin(δ*π/qp_P)^3*cos(δ*π/qp_P)/qp_P^6 + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/qp_P^5 - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/qp_P^5 + 256*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 24*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[3, 1, 0, 0]
        func = 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4) + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) - 48*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^5 - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^5 + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^4*π^4*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^5 + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 12*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[2, 1, 0, 0]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-8*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 8*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3 - 16*δ*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^4) + 2*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[1, 1, 0, 0]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2 - 4*δ*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^3 + 4*δ*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^3) + 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[0, 1, 0, 0]
        func = 4*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*δ*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^2
    end

    if dorder_view==[6, 0, 0, 0]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^6 + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^3 + 45*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2 + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^6*sin(δ*π/qp_P)^2/qp_P^6 - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^6*cos(δ*π/qp_P)^2/qp_P^6 + 2560*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^4*π^6*sin(δ*π/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^6 - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)^2/qp_P^4 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*cos(δ*π/qp_P)^2/qp_P^4 - 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)^2/qp_P^4 + 240*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*cos(δ*π/qp_P)^2/qp_P^4 - 384*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^5*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 + 320*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 960*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3
    end

    if dorder_view==[5, 0, 0, 0]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^5 + 15*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2 + 10*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) - 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^5*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^5 - 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)^2/qp_P^4 + 80*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*cos(δ*π/qp_P)^2/qp_P^4 + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3 + 160*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3
    end

    if dorder_view==[4, 0, 0, 0]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^4 + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))^2 + 6*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) - 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*sin(δ*π/qp_P)^2/qp_P^4 + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^4*cos(δ*π/qp_P)^2/qp_P^4 + 64*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3
    end

    if dorder_view==[3, 0, 0, 0]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^3 + 3*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2)) + 16*exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*p_amp^2*π^3*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P^3
    end

    if dorder_view==[2, 0, 0, 0]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)^2 + exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(4*p_amp^2*π^2*sin(δ*π/qp_P)^2/qp_P^2 - 4*p_amp^2*π^2*cos(δ*π/qp_P)^2/qp_P^2 - se_λ^(-2))
    end

    if dorder_view==[1, 0, 0, 0]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)*(-δ/se_λ^2 - 4*p_amp^2*π*sin(δ*π/qp_P)*cos(δ*π/qp_P)/qp_P)
    end

    if dorder_view==[0, 0, 0, 0]
        func = exp(-2*p_amp^2*sin(δ*π/qp_P)^2 + (-1/2)*δ^2/se_λ^2)
    end

    dorder[2] = dorder2  # resetting dorder[2]
    return powers_of_negative_one(dorder2) * float(func)  # correcting for amount of t2 derivatives

end


return qp_kernel, 3  # the function handle and the number of kernel hyperparameters
